==> doc-adapter-1.2.1.tgz: package/src/splitByPage/Table/TableTransfrom.ts <==
import { TableUtils } from "./TableUtils"


//Трансформирует таблицу в div вид
export class TableTransfrom {

  // Трансформирует таблицу из table тега, в таблицу из div
  static transform(elem: HTMLDivElement) {

    // Создаем строку для шаблона
    const divTemplateRow = document.createElement('div')

    // Создаем таблицу со всеми атрибутами
    const divTable = elem.querySelector('.table')!.cloneNode() as HTMLDivElement
    divTemplateRow.appendChild(divTable)

    // Вставляем в наш скрытый дом, для вычисления ширины в будущем
    TableUtils.insertInHiddenDom(divTemplateRow)

    // Транформируем нашу таблицу из табличного вида в div вид
    const divHeader = this.transformHeader(elem.querySelector('thead') as HTMLTableSectionElement)
    const divBody = this.transformBody(elem.querySelector('tbody') as HTMLTableSectionElement)

    divTable.appendChild(divHeader)
    divTable.appendChild(divBody)

    return divTemplateRow
  }



  static transformRow(row: HTMLTableRowElement) {
    const tableCells = row.cells;
    const divRow = TableUtils.createTableElement('table-row');

    [...tableCells].forEach((tableCell) => {
      divRow.appendChild(this.transformCell(tableCell))
    })

    return divRow
  }

  static transformCell(cell: HTMLTableCellElement): HTMLDivElement {
    const divCell = TableUtils.createTableElement('table-cell')
    const cellType = TableUtils.getCellType(cell)

    if (cellType !== 'other') {

      const constructorField = cell.querySelector(`.${cellType}`)!.cloneNode(true)

      if (cellType == 'text') {

        const wrapperWithMetaFromConstructor = cell.querySelector(`.${cellType}`)!.cloneNode() as HTMLDivElement

        const textContent = (constructorField.childNodes[0] as CharacterData).textContent!

        textContent.split(/\n/).forEach((text) => {
          // Значит это строка с переносом
          if (!text.length) {
            const breakSpaceNode = document.createElement('span')
            breakSpaceNode.textContent = '\n'
            wrapperWithMetaFromConstructor.appendChild(breakSpaceNode)
            return
          }

          const spanWrapper = document.createElement('span')
          const textNode = document.createTextNode(text)

          spanWrapper.appendChild(textNode)
          wrapperWithMetaFromConstructor?.appendChild(spanWrapper)
        })

        wrapperWithMetaFromConstructor.style.display = 'flex'
        wrapperWithMetaFromConstructor.style.flexDirection = 'column'

        divCell.appendChild(wrapperWithMetaFromConstructor)

        return divCell
      }

      divCell.appendChild(constructorField)
      return divCell
    }

    cell.childNodes.forEach(cellChildNode => divCell.appendChild(cellChildNode.cloneNode(true)))
    return divCell
  }

  static transformHeader(tableHeader: HTMLTableSectionElement) {

    const tableRow = tableHeader.querySelector('tr') as HTMLTableRowElement

    const divHeader = TableUtils.createTableElement('table-header')
    const divRow = this.transformRow(tableRow)

    divHeader.appendChild(divRow)

    return divHeader
  }

  static transformBody(tableBody: HTMLTableSectionElement) {
    const tableRows = [...tableBody.querySelectorAll('tr')];

    const divBody = TableUtils.createTableElement('table-body')
    const divRows = tableRows.map((e) => this.transformRow(e))

    divRows.forEach((e) => divBody.appendChild(e))

    return divBody
  }
}

==> doc-adapter-1.2.4.tgz: package/src/splitByPage/Table/TableTransfrom.ts <==
import { TableUtils } from "./TableUtils"


//Трансформирует таблицу в div вид
export class TableTransfrom {

  // Трансформирует таблицу из table тега, в таблицу из div
  static transform(elem: HTMLDivElement) {

    // Создаем строку для шаблона
    const divTemplateRow = document.createElement('div')

    // Создаем таблицу со всеми атрибутами
    const divTable = elem.querySelector('.table')!.cloneNode() as HTMLDivElement
    divTemplateRow.appendChild(divTable)

    // Вставляем в наш скрытый дом, для вычисления ширины в будущем
    TableUtils.insertInHiddenDom(divTemplateRow)

    // Транформируем нашу таблицу из табличного вида в div вид
    const divHeader = this.transformHeader(elem.querySelector('thead') as HTMLTableSectionElement)
    const divBody = this.transformBody(elem.querySelector('tbody') as HTMLTableSectionElement)

    divTable.appendChild(divHeader)
    divTable.appendChild(divBody)

    return divTemplateRow
  }



  static transformRow(row: HTMLTableRowElement) {
    const tableCells = row.cells;
    const divRow = TableUtils.createTableElement('table-row');

    [...tableCells].forEach((tableCell) => {
      divRow.appendChild(this.transformCell(tableCell))
    })

    return divRow
  }

  static transformCell(cell: HTMLTableCellElement): HTMLDivElement {
    const divCell = TableUtils.createTableElement('table-cell')
    const cellType = TableUtils.getCellType(cell)

    if (cellType !== 'other') {

      const constructorField = cell.querySelector(`.${cellType}`)!.cloneNode(true)

      if (cellType == 'text' && constructorField.childNodes[0]) {

        const wrapperWithMetaFromConstructor = cell.querySelector(`.${cellType}`)!.cloneNode() as HTMLDivElement

        const textContent = (constructorField.childNodes[0] as CharacterData).textContent!

        textContent.split(/\n/).forEach((text) => {
          // Значит это строка с переносом
          if (!text.length) {
            const breakSpaceNode = document.createElement('span')
            breakSpaceNode.textContent = '\n'
            wrapperWithMetaFromConstructor.appendChild(breakSpaceNode)
            return
          }

          const spanWrapper = document.createElement('span')
          const textNode = document.createTextNode(text)

          spanWrapper.appendChild(textNode)
          wrapperWithMetaFromConstructor?.appendChild(spanWrapper)
        })

        wrapperWithMetaFromConstructor.style.display = 'flex'
        wrapperWithMetaFromConstructor.style.flexDirection = 'column'

        divCell.appendChild(wrapperWithMetaFromConstructor)

        return divCell
      }

      divCell.appendChild(constructorField)
      return divCell
    }

    cell.childNodes.forEach(cellChildNode => divCell.appendChild(cellChildNode.cloneNode(true)))
    return divCell
  }

  static transformHeader(tableHeader: HTMLTableSectionElement) {

    const tableRow = tableHeader.querySelector('tr') as HTMLTableRowElement

    const divHeader = TableUtils.createTableElement('table-header')
    const divRow = this.transformRow(tableRow)

    divHeader.appendChild(divRow)

    return divHeader
  }

  static transformBody(tableBody: HTMLTableSectionElement) {
    const tableRows = [...tableBody.querySelectorAll('tr')];

    const divBody = TableUtils.createTableElement('table-body')
    const divRows = tableRows.map((e) => this.transformRow(e))

    divRows.forEach((e) => divBody.appendChild(e))

    return divBody
  }
}
